function [u,p] = AcousAdvec1D(u,p,Mach,FinalTime);

% function [u,p] = AcousAdvec1D(u,p,Mach,FinalTime)
% Purpose  : Integrate 1D Advec Acoustics until FinalTime starting 
%             with conditions (u(t=0),p(t=0)) and mean flow Mach.

Globals1D;
time = 0;

% Runge-Kutta residual storage  
resu = zeros(Np,K); resp = zeros(Np,K); 

% compute time step size
xmin = min(abs(x(1,:)-x(2,:)));
CFL=1.0;  
dt = CFL*xmin./max(max(abs(Mach+1)));
Nsteps = ceil(FinalTime/dt); dt = FinalTime/Nsteps;

% outer time step loop 
for tstep=1:Nsteps
   for INTRK = 1:5
      [rhsu, rhsp] = AcousAdvecRHS1D(u,p,Mach);
      
      resu = rk4a(INTRK)*resu + dt*rhsu;
      resp = rk4a(INTRK)*resp + dt*rhsp;
      
      u = u+rk4b(INTRK)*resu;
      p = p+rk4b(INTRK)*resp;
   end 
   % Increment time
   time = time+dt;
   plot(x(:),u(:),x(:),p(:));
   drawnow;
end
return
