function [rhsu, rhsp] = AcousAdvecRHS1D(u,p,Mach)

% function [rhsu, rhsp] = AcousAdvecRHS1D(u,p,Mach)
% Purpose  : Evaluate RHS flux in 1D Maxwell 

Globals1D;

% Define field differences at faces
du = zeros(Nfp*Nfaces,K); du(:) = u(vmapM)-u(vmapP);
dp = zeros(Nfp*Nfaces,K); dp(:) = p(vmapM)-p(vmapP);
Machm = zeros(Nfp*Nfaces,K); Machm(:) = Mach(vmapM);
Machp = zeros(Nfp*Nfaces,K); Machp(:) = Mach(vmapP);

% Homogeneous boundary conditions, u=0
ubc = -u(vmapB); du (mapB) = u(vmapB) - ubc; 
pbc =  p(vmapB); dp (mapB) = p(vmapB) - pbc;

% evaluate upwind fluxes
alpha=0;
fluxu = (nx.*(Machm.*du + dp) - (1-alpha)*(Machm.*dp + du))/2.0;
fluxp = (nx.*(Machm.*dp + du) - (1-alpha)*(Machm.*du + dp))/2.0;

% compute right hand sides of the PDE's
rhsu = (-Mach.*(rx.*(Dr*u)) - rx.*(Dr*p)         + LIFT*(Fscale.*fluxu));
rhsp = (       -rx.*(Dr*u)  - Mach.*(rx.*(Dr*p)) + LIFT*(Fscale.*fluxp));
return
